@@ -10,8 +10,6 @@
 use std::cell::{Cell, Ref, RefCell};
 use std::cmp::min;
 use std::fs::File;
-use std::i32;
-use std::i64;
 use std::io::{stderr, Cursor, Write};
 use std::marker::PhantomData;
 use std::os::unix::io::{AsRawFd, FromRawFd, IntoRawFd, RawFd};
@@ -157,7 +155,7 @@ impl<T> std::fmt::Debug for PollEvent<'_, T> {
     }
 }
 
-impl<'a, T: PollToken> PollEvent<'a, T> {
+impl<T: PollToken> PollEvent<'_, T> {
     /// Gets the token associated in
     /// [`PollContext::add`](struct.PollContext.html#method.add) with this event.
     pub fn token(&self) -> T {
@@ -248,7 +246,7 @@ impl<T> std::fmt::Debug for PollEvents<'_, T> {
     }
 }
 
-impl<'a, T: PollToken> PollEvents<'a, T> {
+impl<T: PollToken> PollEvents<'_, T> {
     /// Creates owned structure from borrowed [`PollEvents`](struct.PollEvents.html).
     ///
     /// Copies the events to an owned structure so the reference to this (and by extension
@@ -663,7 +661,7 @@ impl<T: PollToken> EpollContext<T> {
         events: &'a EpollEvents,
         timeout: Duration,
     ) -> Result<PollEvents<'a, T>> {
-        let timeout_millis = if timeout.as_secs() as i64 == i64::max_value() {
+        let timeout_millis = if timeout.as_secs() as i64 == i64::MAX {
             // We make the convenient assumption that 2^63 seconds is an effectively unbounded time
             // frame. This is meant to mesh with `wait` calling us with no timeout.
             -1
@@ -674,8 +672,8 @@ impl<T: PollToken> EpollContext<T> {
                 .as_secs()
                 .checked_mul(1_000)
                 .and_then(|ms| ms.checked_add(u64::from(timeout.subsec_nanos()) / 1_000_000))
-                .unwrap_or(i32::max_value() as u64);
-            min(i32::max_value() as u64, millis) as i32
+                .unwrap_or(i32::MAX as u64);
+            min(i32::MAX as u64, millis) as i32
         };
         let ret = {
             let mut epoll_events = events.0.borrow_mut();
