@@ -1,5 +1,7 @@
 // Copyright 2022 rust-vmm Authors or its affiliates. All Rights Reserved.
 // SPDX-License-Identifier: BSD-3-Clause
+pub mod event;
 pub mod file_traits;
+pub mod sock_ctrl_msg;
 pub mod tempdir;
 pub mod terminal;
